Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/monodevelop.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMike Krüger <mkrueger@xamarin.com>2016-09-22 09:21:08 +0300
committerMike Krüger <mkrueger@xamarin.com>2016-09-22 09:21:08 +0300
commit1492f3113f745a920c175285b408c47688e76b74 (patch)
treeb827d7483dfbbc9d2ae1cf7fa86454b7fd5c90c3 /main/src/core/MonoDevelop.Ide/gtk-gui
parentbb1be20623b915400dfaecb347d52c5fb2f7698a (diff)
[Ide] Overworked the appearance of the language bundle options panel.
Diffstat (limited to 'main/src/core/MonoDevelop.Ide/gtk-gui')
-rw-r--r--main/src/core/MonoDevelop.Ide/gtk-gui/MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget.cs121
-rw-r--r--main/src/core/MonoDevelop.Ide/gtk-gui/gui.stetic86
2 files changed, 79 insertions, 128 deletions
diff --git a/main/src/core/MonoDevelop.Ide/gtk-gui/gui.stetic b/main/src/core/MonoDevelop.Ide/gtk-gui/gui.stetic
index 9887d0016a..467cb1479b 100644
--- a/main/src/core/MonoDevelop.Ide/gtk-gui/gui.stetic
+++ b/main/src/core/MonoDevelop.Ide/gtk-gui/gui.stetic
@@ -12101,7 +12101,7 @@ Visual Studio generates a default ID for embedded resources, instead of simply u
</widget>
</child>
</widget>
- <widget class="Gtk.Bin" id="MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget" design-size="1359 400">
+ <widget class="Gtk.Bin" id="MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget" design-size="884 413">
<property name="MemberName" />
<property name="Visible">False</property>
<child>
@@ -12109,27 +12109,29 @@ Visual Studio generates a default ID for embedded resources, instead of simply u
<property name="MemberName" />
<property name="Spacing">6</property>
<child>
- <widget class="Gtk.Label" id="GtkLabel5">
- <property name="MemberName" />
- <property name="Xalign">0</property>
- <property name="LabelProp" translatable="yes">&lt;b&gt;Language bundles&lt;/b&gt;</property>
- <property name="UseMarkup">True</property>
- </widget>
- <packing>
- <property name="Position">0</property>
- <property name="AutoSize">True</property>
- <property name="Expand">False</property>
- <property name="Fill">False</property>
- </packing>
- </child>
- <child>
- <widget class="Gtk.Alignment" id="GtkAlignment">
+ <widget class="Gtk.VBox" id="vbox5">
<property name="MemberName" />
- <property name="Xalign">0</property>
- <property name="Yalign">0</property>
- <property name="LeftPadding">12</property>
+ <property name="Spacing">6</property>
<child>
- <widget class="Gtk.VBox" id="vbox5">
+ <widget class="Gtk.TextView" id="textview1">
+ <property name="MemberName" />
+ <property name="Sensitive">False</property>
+ <property name="Editable">False</property>
+ <property name="CursorVisible">False</property>
+ <property name="AcceptsTab">False</property>
+ <property name="Text" translatable="yes">Language bundles can provide new editor themes, code snippets, code completion items and other information to improve the editing experience of specific languages. Xamarin Studio supports: &lt;b&gt;TextMate (.tmBundle)&lt;/b&gt; and &lt;b&gt;Sublime 3 (.sublime)&lt;/b&gt; package files.</property>
+ <property name="WrapMode">Word</property>
+ <property name="PixelsBelowLines">6</property>
+ <property name="PixelsInsideWrap">3</property>
+ </widget>
+ <packing>
+ <property name="Position">0</property>
+ <property name="AutoSize">False</property>
+ <property name="Expand">False</property>
+ </packing>
+ </child>
+ <child>
+ <widget class="Gtk.HBox" id="hbox1">
<property name="MemberName" />
<property name="Spacing">6</property>
<child>
@@ -12158,23 +12160,7 @@ Visual Studio generates a default ID for embedded resources, instead of simply u
</packing>
</child>
<child>
- <widget class="Gtk.Label" id="label2">
- <property name="MemberName" />
- <property name="Xalign">0</property>
- <property name="LabelProp" translatable="yes">Language bundles can provide new editor themes, code snippets, code completion items and
-other information to improve the editing experience of specific languages.
-Xamarin Studio supports:
-*TextMate (.tmBundle)* and *Sublime 3 (.sublime)* package files.</property>
- </widget>
- <packing>
- <property name="Position">1</property>
- <property name="AutoSize">True</property>
- <property name="Expand">False</property>
- <property name="Fill">False</property>
- </packing>
- </child>
- <child>
- <widget class="Gtk.HBox" id="hbox2">
+ <widget class="Gtk.VBox" id="vbox1">
<property name="MemberName" />
<property name="Spacing">6</property>
<child>
@@ -12187,7 +12173,6 @@ Xamarin Studio supports:
<property name="label">gtk-add</property>
</widget>
<packing>
- <property name="PackType">End</property>
<property name="Position">0</property>
<property name="AutoSize">True</property>
<property name="Expand">False</property>
@@ -12204,7 +12189,6 @@ Xamarin Studio supports:
<property name="label">gtk-remove</property>
</widget>
<packing>
- <property name="PackType">End</property>
<property name="Position">1</property>
<property name="AutoSize">True</property>
<property name="Expand">False</property>
@@ -12212,35 +12196,25 @@ Xamarin Studio supports:
</packing>
</child>
<child>
- <widget class="Gtk.Button" id="buttonEdit">
- <property name="MemberName" />
- <property name="CanFocus">True</property>
- <property name="Type">TextOnly</property>
- <property name="Label" translatable="yes">_Edit</property>
- <property name="UseUnderline">True</property>
- </widget>
- <packing>
- <property name="PackType">End</property>
- <property name="Position">2</property>
- <property name="AutoSize">True</property>
- <property name="Expand">False</property>
- <property name="Fill">False</property>
- </packing>
+ <placeholder />
</child>
</widget>
<packing>
- <property name="PackType">End</property>
- <property name="Position">2</property>
+ <property name="Position">1</property>
<property name="AutoSize">True</property>
<property name="Expand">False</property>
<property name="Fill">False</property>
</packing>
</child>
</widget>
+ <packing>
+ <property name="Position">1</property>
+ <property name="AutoSize">True</property>
+ </packing>
</child>
</widget>
<packing>
- <property name="Position">1</property>
+ <property name="Position">0</property>
<property name="AutoSize">True</property>
</packing>
</child>
diff --git a/main/src/core/MonoDevelop.Ide/gtk-gui/MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget.cs b/main/src/core/MonoDevelop.Ide/gtk-gui/MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget.cs
index d3d7c385c3..bba735251a 100644
--- a/main/src/core/MonoDevelop.Ide/gtk-gui/MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget.cs
+++ b/main/src/core/MonoDevelop.Ide/gtk-gui/MonoDevelop.Ide.Editor.TextMate.TextMateBundleOptionsPanelWidget.cs
@@ -6,26 +6,22 @@ namespace MonoDevelop.Ide.Editor.TextMate
{
private global::Gtk.VBox vbox4;
- private global::Gtk.Label GtkLabel5;
+ private global::Gtk.VBox vbox5;
- private global::Gtk.Alignment GtkAlignment;
+ private global::Gtk.TextView textview1;
- private global::Gtk.VBox vbox5;
+ private global::Gtk.HBox hbox1;
private global::Gtk.ScrolledWindow scrolledwindow1;
private global::Gtk.TreeView bundleTreeview;
- private global::Gtk.Label label2;
-
- private global::Gtk.HBox hbox2;
+ private global::Gtk.VBox vbox1;
private global::Gtk.Button addButton;
private global::Gtk.Button removeButton;
- private global::Gtk.Button buttonEdit;
-
protected virtual void Build()
{
global::Stetic.Gui.Initialize(this);
@@ -37,25 +33,29 @@ namespace MonoDevelop.Ide.Editor.TextMate
this.vbox4.Name = "vbox4";
this.vbox4.Spacing = 6;
// Container child vbox4.Gtk.Box+BoxChild
- this.GtkLabel5 = new global::Gtk.Label();
- this.GtkLabel5.Name = "GtkLabel5";
- this.GtkLabel5.Xalign = 0F;
- this.GtkLabel5.LabelProp = global::Mono.Unix.Catalog.GetString("<b>Language bundles</b>");
- this.GtkLabel5.UseMarkup = true;
- this.vbox4.Add(this.GtkLabel5);
- global::Gtk.Box.BoxChild w1 = ((global::Gtk.Box.BoxChild)(this.vbox4[this.GtkLabel5]));
- w1.Position = 0;
- w1.Expand = false;
- w1.Fill = false;
- // Container child vbox4.Gtk.Box+BoxChild
- this.GtkAlignment = new global::Gtk.Alignment(0F, 0F, 1F, 1F);
- this.GtkAlignment.Name = "GtkAlignment";
- this.GtkAlignment.LeftPadding = ((uint)(12));
- // Container child GtkAlignment.Gtk.Container+ContainerChild
this.vbox5 = new global::Gtk.VBox();
this.vbox5.Name = "vbox5";
this.vbox5.Spacing = 6;
// Container child vbox5.Gtk.Box+BoxChild
+ this.textview1 = new global::Gtk.TextView();
+ this.textview1.Buffer.Text = "Language bundles can provide new editor themes, code snippets, code completion items and other information to improve the editing experience of specific languages. Xamarin Studio supports: <b>TextMate (.tmBundle)</b> and <b>Sublime 3 (.sublime)</b> package files.";
+ this.textview1.Sensitive = false;
+ this.textview1.Name = "textview1";
+ this.textview1.Editable = false;
+ this.textview1.CursorVisible = false;
+ this.textview1.AcceptsTab = false;
+ this.textview1.WrapMode = ((global::Gtk.WrapMode)(2));
+ this.textview1.PixelsBelowLines = 6;
+ this.textview1.PixelsInsideWrap = 3;
+ this.vbox5.Add(this.textview1);
+ global::Gtk.Box.BoxChild w1 = ((global::Gtk.Box.BoxChild)(this.vbox5[this.textview1]));
+ w1.Position = 0;
+ w1.Expand = false;
+ // Container child vbox5.Gtk.Box+BoxChild
+ this.hbox1 = new global::Gtk.HBox();
+ this.hbox1.Name = "hbox1";
+ this.hbox1.Spacing = 6;
+ // Container child hbox1.Gtk.Box+BoxChild
this.scrolledwindow1 = new global::Gtk.ScrolledWindow();
this.scrolledwindow1.CanFocus = true;
this.scrolledwindow1.Name = "scrolledwindow1";
@@ -70,71 +70,48 @@ namespace MonoDevelop.Ide.Editor.TextMate
this.bundleTreeview.HeadersVisible = false;
w2.Add(this.bundleTreeview);
this.scrolledwindow1.Add(w2);
- this.vbox5.Add(this.scrolledwindow1);
- global::Gtk.Box.BoxChild w5 = ((global::Gtk.Box.BoxChild)(this.vbox5[this.scrolledwindow1]));
+ this.hbox1.Add(this.scrolledwindow1);
+ global::Gtk.Box.BoxChild w5 = ((global::Gtk.Box.BoxChild)(this.hbox1[this.scrolledwindow1]));
w5.Position = 0;
- // Container child vbox5.Gtk.Box+BoxChild
- this.label2 = new global::Gtk.Label();
- this.label2.Name = "label2";
- this.label2.Xalign = 0F;
- this.label2.LabelProp = global::Mono.Unix.Catalog.GetString("Language bundles can provide new editor themes, code snippets, code completion items and\nother information to improve the editing experience of specific languages.\nXamarin Studio supports:\n*TextMate (.tmBundle)* and *Sublime 3 (.sublime)* package files.");
- this.vbox5.Add(this.label2);
- global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.vbox5[this.label2]));
- w6.Position = 1;
- w6.Expand = false;
- w6.Fill = false;
- // Container child vbox5.Gtk.Box+BoxChild
- this.hbox2 = new global::Gtk.HBox();
- this.hbox2.Name = "hbox2";
- this.hbox2.Spacing = 6;
- // Container child hbox2.Gtk.Box+BoxChild
+ // Container child hbox1.Gtk.Box+BoxChild
+ this.vbox1 = new global::Gtk.VBox();
+ this.vbox1.Name = "vbox1";
+ this.vbox1.Spacing = 6;
+ // Container child vbox1.Gtk.Box+BoxChild
this.addButton = new global::Gtk.Button();
this.addButton.CanFocus = true;
this.addButton.Name = "addButton";
this.addButton.UseStock = true;
this.addButton.UseUnderline = true;
this.addButton.Label = "gtk-add";
- this.hbox2.Add(this.addButton);
- global::Gtk.Box.BoxChild w7 = ((global::Gtk.Box.BoxChild)(this.hbox2[this.addButton]));
- w7.PackType = ((global::Gtk.PackType)(1));
- w7.Position = 0;
- w7.Expand = false;
- w7.Fill = false;
- // Container child hbox2.Gtk.Box+BoxChild
+ this.vbox1.Add(this.addButton);
+ global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.vbox1[this.addButton]));
+ w6.Position = 0;
+ w6.Expand = false;
+ w6.Fill = false;
+ // Container child vbox1.Gtk.Box+BoxChild
this.removeButton = new global::Gtk.Button();
this.removeButton.CanFocus = true;
this.removeButton.Name = "removeButton";
this.removeButton.UseStock = true;
this.removeButton.UseUnderline = true;
this.removeButton.Label = "gtk-remove";
- this.hbox2.Add(this.removeButton);
- global::Gtk.Box.BoxChild w8 = ((global::Gtk.Box.BoxChild)(this.hbox2[this.removeButton]));
- w8.PackType = ((global::Gtk.PackType)(1));
+ this.vbox1.Add(this.removeButton);
+ global::Gtk.Box.BoxChild w7 = ((global::Gtk.Box.BoxChild)(this.vbox1[this.removeButton]));
+ w7.Position = 1;
+ w7.Expand = false;
+ w7.Fill = false;
+ this.hbox1.Add(this.vbox1);
+ global::Gtk.Box.BoxChild w8 = ((global::Gtk.Box.BoxChild)(this.hbox1[this.vbox1]));
w8.Position = 1;
w8.Expand = false;
w8.Fill = false;
- // Container child hbox2.Gtk.Box+BoxChild
- this.buttonEdit = new global::Gtk.Button();
- this.buttonEdit.CanFocus = true;
- this.buttonEdit.Name = "buttonEdit";
- this.buttonEdit.UseUnderline = true;
- this.buttonEdit.Label = global::Mono.Unix.Catalog.GetString("_Edit");
- this.hbox2.Add(this.buttonEdit);
- global::Gtk.Box.BoxChild w9 = ((global::Gtk.Box.BoxChild)(this.hbox2[this.buttonEdit]));
- w9.PackType = ((global::Gtk.PackType)(1));
- w9.Position = 2;
- w9.Expand = false;
- w9.Fill = false;
- this.vbox5.Add(this.hbox2);
- global::Gtk.Box.BoxChild w10 = ((global::Gtk.Box.BoxChild)(this.vbox5[this.hbox2]));
- w10.PackType = ((global::Gtk.PackType)(1));
- w10.Position = 2;
- w10.Expand = false;
- w10.Fill = false;
- this.GtkAlignment.Add(this.vbox5);
- this.vbox4.Add(this.GtkAlignment);
- global::Gtk.Box.BoxChild w12 = ((global::Gtk.Box.BoxChild)(this.vbox4[this.GtkAlignment]));
- w12.Position = 1;
+ this.vbox5.Add(this.hbox1);
+ global::Gtk.Box.BoxChild w9 = ((global::Gtk.Box.BoxChild)(this.vbox5[this.hbox1]));
+ w9.Position = 1;
+ this.vbox4.Add(this.vbox5);
+ global::Gtk.Box.BoxChild w10 = ((global::Gtk.Box.BoxChild)(this.vbox4[this.vbox5]));
+ w10.Position = 0;
this.Add(this.vbox4);
if ((this.Child != null))
{